@@ -7,6 +7,8 @@ from .poisoning import Poison
 from .replace_label import ReplaceLabel
 from .normalize import NormalizeImage
 from .translate import RandomTranslate
+from .mixup import ImageMixup, LabelMixup, MixupToOneHot
+from .module import ModuleWrapper
 
 __all__ = ['ToTensor', 'ToDevice',
            'ToTorchImage', 'NormalizeImage',
